## 债券回购日行情

接口：repo_daily

描述：债券回购日行情

限量：单次最大2000条，可多次提取，总量不限制

权限：用户需要累积2000积分才可以调取，具体请参阅积分获取办法

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | TS代码 |
| trade_date | str | N | 交易日期(YYYYMMDD格式，下同) |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | TS代码 |
| trade_date | str | Y | 交易日期 |
| repo_maturity | str | Y | 期限品种 |
| pre_close | float | Y | 前收盘(%) |
| open | float | Y | 开盘价(%) |
| high | float | Y | 最高价(%) |
| low | float | Y | 最低价(%) |
| close | float | Y | 收盘价(%) |
| weight | float | Y | 加权价(%) |
| weight_r | float | Y | 加权价(利率债)(%) |
| amount | float | Y | 成交金额(万元) |
| num | int | Y | 成交笔数(笔) |

接口使用

```python
pro = ts.pro_api()

#获取2020年8月4日债券回购日行情
df = pro.repo_daily(trade_date='20200804')
```

数据样例

```python
ts_code trade_date repo_maturity      weight            amount
0   131800.SZ   20200804         R-003  2.02150000      42783.000000
```